@@ -2,11 +2,16 @@ from abc import ABCMeta, abstractmethod
 from functools import lru_cache
 import os, dotenv
 
-from fastapi import FastAPI, Request
+import watchtower
+from fastapi import FastAPI, HTTPException, Request
+from fastapi.responses import JSONResponse
+from fastapi.middleware.cors import CORSMiddleware
 from starlette.concurrency import iterate_in_threadpool
 import logging
 
 from .const import LOG_DEFAULT_LOGGER_NAME, LOG_FMT
+from .ext.aws import init_app as init_aws_app
+from .exception.base_exception import InternalBaseException
 from .utils import update_dict_with_cast
 
 class BaseFactory(metaclass=ABCMeta):
@@ -34,6 +39,15 @@ class BaseFactory(metaclass=ABCMeta):
         logger.addHandler(stream_handler)
         return logger
 
+    def __setup_aws_cloud_log(self, app):
+        if app.state.aws_session and app.state.config.get("AWS_LOGGROUP_NAME"):
+            logs_client = app.state.aws_session.client("logs")
+            watchtower_handler = watchtower.CloudWatchLogHandler(
+                log_group_name=app.state.config.get("AWS_LOGGROUP_NAME"),
+                boto3_client=logs_client, create_log_group=True)
+            watchtower_handler.setFormatter(logging.Formatter(LOG_FMT))
+            app.logger.addHandler(watchtower_handler)
+
     def create_app(self):
         """
         Create an application instance.
@@ -43,7 +57,27 @@ class BaseFactory(metaclass=ABCMeta):
         app = FastAPI(docs_url=app_config.get('DOCS_URL'), redoc_url=app_config.get('REDOC_URL'), openapi_url=app_config.get('OPENAPI_URL'))
         app.state.config = app_config
 
+        app.add_middleware(
+            CORSMiddleware,
+            allow_origins=['*'],
+            allow_credentials=True,
+            allow_methods=['*'],
+            allow_headers=['*'],
+        )
         self.__setup_main_logger(app, logger_name=app.state.config.get('LOGGER_NAME', LOG_DEFAULT_LOGGER_NAME), level=logging.DEBUG)
+        app.state.aws_session = init_aws_app(app)
+        self.__setup_aws_cloud_log(app)
+
+        @app.exception_handler(InternalBaseException)
+        async def http_exception_handler(request: Request, exc: InternalBaseException):
+            return JSONResponse(
+                status_code=exc.status_code,
+                content={
+                    "code": exc.detail["code"],
+                    "message": exc.detail["message"],
+                    "data": exc.detail["data"]
+                }
+            )
 
         @app.middleware("http")
         async def handle_request_headers(request: Request, call_next):
